@@ -26,6 +26,10 @@
 
 #define QT_FEATURE_linkat 1
 
+#define QT_FEATURE_memmem 1
+
+#define QT_FEATURE_memrchr 1
+
 #define QT_FEATURE_mimetype_database 1
 
 #define QT_FEATURE_system_pcre2 1
@@ -56,12 +60,16 @@
 
 #define QT_FEATURE_backtrace 1
 
+#define QT_FEATURE_cxx23_stacktrace -1
+
 #define QT_FEATURE_cpp_winrt -1
 
 #define QT_FEATURE_sha3_fast 1
 
 #define QT_FEATURE_hijricalendar 1
 
+#define QT_FEATURE_timezone_locale 1
+
 #define QT_FEATURE_datetimeparser 1
 
 #define QT_FEATURE_lttng -1
